@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+"""#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 from shimehari import Request, Response, ApplicationController
@@ -29,3 +29,4 @@ class %sController(ApplicationController):
 
     def destroy(self, *args, **kwargs):
         pass
+"""
\ No newline at end of file
